@@ -21,7 +21,8 @@ class Config(_Singleton):
         self._verbosity: int = 0
         self._patched_function: tp.Dict[
             callable, tp.Tuple[str, str, callable]] = {}
-        self._registered_gradient_function: tp.Dict[callable, callable] = {}
+        self._registered_vjp_funcs: tp.Dict[
+            tp.Callable, tp.Tuple[tp.Callable, ...]] = {}
 
     @property
     def dtype(self) -> type:
